package pl.spjava.demospringboot.dto;

import jakarta.validation.constraints.Email;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.Size;
import lombok.*;

import java.util.UUID;

@AllArgsConstructor
@RequiredArgsConstructor
@NoArgsConstructor
@ToString
@EqualsAndHashCode(onlyExplicitlyIncluded = true)
public class PersonDTO implements Cloneable{

    @Getter @Setter
    @EqualsAndHashCode.Include
    private UUID id;

    @NonNull
    @Getter @Setter
    @NotBlank @NotEmpty
    @Size(min=3)
    private String login;

    @NonNull
    @Getter @Setter
    @ToString.Exclude
    @NotBlank @NotEmpty
    private String password;

    @NonNull
    @Email
    @Getter @Setter
    @NotBlank @NotEmpty
    private String email;

    @NonNull
    @Getter @Setter
    private Long age;

    // active has to be false by default, so no @NonNull
    @Getter @Setter
    private boolean active;

    @Getter @Setter
    private Long version;

    @Override
    public PersonDTO clone() {
        try {
            return (PersonDTO) super.clone();
        } catch (CloneNotSupportedException e) {
            return new PersonDTO();
        }
    }
}
