package pl.spjava.demospringboot.entities;

import jakarta.persistence.*;
import jakarta.validation.constraints.Email;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.Size;
import lombok.*;

import java.util.UUID;


@NoArgsConstructor
@RequiredArgsConstructor
@ToString
@EqualsAndHashCode(onlyExplicitlyIncluded = true)
@Entity
@Table(name = "person")
public class PersonEntity extends AbstractEntity implements Cloneable{

    @NonNull
    @Getter @Setter
    @NotBlank @NotEmpty
    @Size(min=3)
    @Column(unique = true, nullable = false)
    private String login;

    @NonNull
    @Getter @Setter
    @ToString.Exclude
    @NotBlank @NotEmpty
    @Column(nullable = false)
    private String password;

    @NonNull
    @Email
    @Getter @Setter
    @NotBlank @NotEmpty
    private String email;

    @NonNull
    @Getter @Setter
    private Long age;

    // active has to be false by default, so no @NonNull
    @Getter @Setter
    private boolean active;

    @Override
    public PersonEntity clone() {
        try {
            return (PersonEntity) super.clone();
        } catch (CloneNotSupportedException e) {
            return new PersonEntity();
        }
    }
}
