package pl.spjava.demospringboot.repositories;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.data.repository.CrudRepository;
import org.springframework.data.repository.ListPagingAndSortingRepository;
import org.springframework.data.repository.NoRepositoryBean;
import org.springframework.data.repository.PagingAndSortingRepository;
import pl.spjava.demospringboot.interceptors.MethodCallLogged;

import java.util.List;
import java.util.Optional;
import java.util.UUID;

/*
SpringData repository interfaces: https://docs.spring.io/spring-data/jpa/reference/repositories/core-concepts.html

The interface method identifier determines what has to be done. No need to write code.

From CrudRepository we have already all CRUD, i.e:
long count() Returns the number of entities available.
void delete(T entity) Deletes a given entity.
void deleteAll() Deletes all entities managed by the repository.
void deleteAll(Iterable<? extends T> entities) Deletes the given entities.
void deleteAllById(Iterable<? extends ID> ids) Deletes all instances of the type T with the given IDs.
void deleteById(ID id) Deletes the entity with the given id.
boolean existsById(ID id) Returns whether an entity with the given id exists.
Optional<T> findById(ID id) Retrieves an entity by its id.
<S extends T> S save(S entity) Saves a given entity.
<S extends T> Iterable<S> saveAll(Iterable<S> entities) Saves all given entities.

From ListPagingAndSortingRepository we have more:
List<T> findAll() Returns all instances of the type.
List<T> findAllById(Iterable<ID> ids) Returns all instances of the type T with the given IDs
List<T> findAll(Sort sort) Returns all entities sorted by the given options.

 */

// Here we just define that ID is always UUID. The entity class is still not defined.
// It is not usable now. We're going to use subinterfaces. That's why @NoRepositoryBean is used
@NoRepositoryBean
public interface AbstractRepository<T> extends ListPagingAndSortingRepository<T, UUID>, CrudRepository<T, UUID> {
 // Looks stupid now, as it has no methods. But this may change in future.
}
