package pl.spjava.demospringboot.security;

import jakarta.annotation.security.PermitAll;
import jakarta.validation.Valid;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import org.springframework.http.MediaType;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import pl.spjava.demospringboot.converters.PersonConverter;
import pl.spjava.demospringboot.dto.PersonDTO;
import pl.spjava.demospringboot.dto.PersonUpdateCmdDTO;
import pl.spjava.demospringboot.interceptors.MethodCallLogged;
import pl.spjava.demospringboot.services.PersonService;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

@RestController
@MethodCallLogged
@RequestMapping(value = "/login")
@RequiredArgsConstructor
@PreAuthorize("permitAll()")
public class LoginController {

    @NonNull
    private final JWTGeneratorVerifier jwtGeneratorVerifier;
    // Injection is done by constructor generated by @RequiredArgsConstructor. This allows field to be final and makes mocking easier.
    // In Spring, if there's a constructor for given field, and the field's class is a component, you don't even need to mark the constructor parameter as @Autowired

    // This implementation is COMPLETELY FAKE - for demonstration purpose only
    @PostMapping(value = "", consumes = MediaType.APPLICATION_JSON_VALUE, produces = MediaType.TEXT_PLAIN_VALUE)
    public String login(@RequestBody @Valid LoginDTO loginDTO) {
        // We completely ignore password (do not verify credentials)
        // and grant some groups (roles) based on login ;)
        List<String> groups = new ArrayList<>();
        if("boss".equals(loginDTO.getLogin()) || "employee".equals(loginDTO.getLogin()))  groups.add("EMPLOYEE");
        if("boss".equals(loginDTO.getLogin())) groups.add("ADMIN");

        return jwtGeneratorVerifier.generateJWTString(loginDTO.getLogin(),groups);
    }
}
